@@ -1,5 +1,13 @@
 from .factory import create_sync_processor, create_async_processor
-from . import annotations, contents, genes, therapies, transcripts, trials
+from . import (
+    annotations,
+    contents,
+    genes,
+    therapies,
+    transcripts,
+    trials,
+    variant_interpretations,
+)
 
 __all__ = (
     "create_sync_processor",
@@ -10,4 +18,5 @@ __all__ = (
     "therapies",
     "transcripts",
     "trials",
+    "variant_interpretations",
 )
