@@ -16,6 +16,7 @@ VARIANT_TYPE_BLACKLIST = [
     "Diplotype",
 ]
 
+ACCESSION = "Accession"
 ASSEMBLY = "Assembly"
 CLINICAL_ASSERTION = "ClinicalAssertion"
 CLINICAL_ASSERTION_ID = "ClinicalAssertionID"
@@ -354,6 +355,7 @@ class ClinvarXMLSource(LazyFileSource):
             chromosome = csra_array[0].replace("chr", "")
             position = csra_array[1]
         genes, _ = self.get_genes(interpreted_record)
+        accession = variation_archive.attrib.get(ACCESSION)
 
         # build top-level result dict with fields that could be parsed
         record = {}
@@ -379,6 +381,8 @@ class ClinvarXMLSource(LazyFileSource):
             record["position"] = position
         if len(genes) > 0:
             record["gene"] = genes
+        if accession is not None:
+            record["accession__string"] = accession
         record["alterations"] = list(alterations)
         record["csra"] = csra
         record = self.iterate_individual_submissions(
