@@ -135,3 +135,8 @@ def add_rollup(value, key="__rollup__"):
             call_list.append(ref_call)
     rollup = list(map(filter_private_keys, call_list))
     return map(lambda child: assoc(child, key, rollup), value)
+
+
+def turn_gene_to_list(x):
+    gene = x.get("gene")
+    return [gene] if gene else []
