@@ -21,8 +21,10 @@ from . import (
     uniprot,
     mitomap,
     gene_type,
-    pli,
+    gnomad_gene,
     secondary_findings_genes,
+    mito_trna,
+    mtdb,
 )
 
 __all__ = (
@@ -49,6 +51,8 @@ __all__ = (
     "uniprot",
     "mitomap",
     "gene_type",
-    "pli",
+    "gnomad_gene",
     "secondary_findings_genes",
+    "mito_trna",
+    "mtdb",
 )
